@@ -14,16 +14,14 @@
 
 namespace Breeze
 {
+//* keyboard accelerators
 class Mnemonics : public QObject
 {
     Q_OBJECT
 
 public:
     //* constructor
-    explicit Mnemonics(QObject *parent)
-        : QObject(parent)
-    {
-    }
+    explicit Mnemonics();
 
     //* set mode
     void setMode(int);
